@@ -12,12 +12,25 @@ PlayerSheet::PlayerSheet(QWidget *parent) :
     connect(ui->reduce1Button,SIGNAL(clicked()),this,SLOT(reduceLife1()));
     connect(ui->add5Button,SIGNAL(clicked()),this,SLOT(increaseLife5()));
     connect(ui->reduce5Button,SIGNAL(clicked()),this,SLOT(reduceLife5()));
-    connect(ui->closeButton,SIGNAL(clicked()),this,SLOT(closeSheet()));    
+    connect(ui->closeButton,SIGNAL(clicked()),this,SLOT(closeSheet()));
+
+    connect(ui->lifeLineEdit,SIGNAL(resizeComplete()),this,SLOT(lifeResized()));
 
     ui->add1Button->setChangeAmount(1);
     ui->add5Button->setChangeAmount(5);
     ui->reduce1Button->setChangeAmount(-1);
-    ui->reduce5Button->setChangeAmount(-5);
+    ui->reduce5Button->setChangeAmount(-5);  
+
+    ui->lifeLineEdit->padding = 25;
+
+    poisonBox = new QLineEditScaledFont(this);
+    poisonBox->setText("0");
+    poisonBox->setStyleSheet("QLineEdit { background: transparent; \
+                                          border-image: url(:/images/poison.png); \
+                                          padding: 0px; }");
+    poisonBox->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+    poisonBox->padding = 0;
+    poisonBox->setInputMethodHints(Qt::ImhDigitsOnly);
 }
 
 PlayerSheet::~PlayerSheet()
@@ -94,5 +107,14 @@ void PlayerSheet::SetPlayerName(QString name)
 void PlayerSheet::Reset()
 {
     ui->lifeLineEdit->setText("20");
+    poisonBox->setText("0");
+}
+
+void PlayerSheet::lifeResized()
+{
+    poisonBox->resize(ui->lifeLineEdit->width()/4,ui->lifeLineEdit->height()/4);
+    poisonBox->resize(poisonBox->height(),poisonBox->height());
+    poisonBox->move(ui->lifeLineEdit->pos().x() + ui->lifeLineEdit->width() - poisonBox->width(),
+                 ui->lifeLineEdit->pos().y() + ui->lifeLineEdit->height() - poisonBox->height());
 }
 
