@@ -4,6 +4,7 @@
 #include <QWidget>
 #include <QGesture>
 #include <QGestureEvent>
+#include "qlineeditscaledfont.h"
 
 namespace Ui {
     class PlayerSheet;
@@ -24,7 +25,8 @@ signals:
     void closeSheetSignal(PlayerSheet*);
 
 private:
-    Ui::PlayerSheet *ui;    
+    Ui::PlayerSheet *ui;
+    QLineEditScaledFont *poisonBox;
 
 private slots:
     void closeSheet();
@@ -32,6 +34,7 @@ private slots:
     void reduceLife1();
     void increaseLife5();
     void reduceLife5();
+    void lifeResized();
 };
 
 #endif // PLAYERSHEET_H
