@@ -5,9 +5,9 @@
 #include <QtGui>
 
 MainWindow::MainWindow(QWidget *parent) :
-    QMainWindow(parent),
-    ui(new Ui::MainWindow),
-    list(new QList<PlayerSheet*>)
+        QMainWindow(parent),
+        ui(new Ui::MainWindow),
+        list(new QList<PlayerSheet*>)
 {
     ui->setupUi(this);
 
@@ -15,12 +15,25 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(ui->actionFlip_Orientation,SIGNAL(triggered()),this,SLOT(FlipOrientation()));
     connect(ui->actionFlip_Coin,SIGNAL(triggered()),this,SLOT(FlipCoin()));
     connect(ui->actionReset, SIGNAL(triggered()), this,SLOT(ResetSheets()));
+    connect(ui->actionAbout, SIGNAL(triggered()), this, SLOT(About()));
 
     AddPlayer();
     AddPlayer();
-    coinLabel = NULL;
+
+    coinLabel = new QLabel(this);
 
 
+    aboutFrame = new QFrame(this);
+    aboutLayout = new QVBoxLayout(aboutFrame);
+    aboutLabel = new QLabel(aboutFrame);
+
+    aboutFrame->setLayout(aboutLayout);
+    aboutLayout->addWidget(aboutLabel);
+
+    aboutFrame->resize(100,60);
+    aboutFrame->setAutoFillBackground(true);
+    aboutFrame->setFrameShape(QFrame::Box);
+    aboutFrame->hide();
 }
 
 MainWindow::~MainWindow()
@@ -31,7 +44,7 @@ MainWindow::~MainWindow()
 void MainWindow::FlipOrientation()
 {
 
-    #ifdef Q_WS_MAEMO_5
+#ifdef Q_WS_MAEMO_5
     static bool portraitMode = false;
     if(portraitMode == false)
     {
@@ -44,7 +57,7 @@ void MainWindow::FlipOrientation()
         portraitMode = false;
     }
     emit StartTimerSignal(1000);
-    #endif
+#endif
 }
 
 
@@ -64,7 +77,7 @@ void MainWindow::SheetClose(PlayerSheet* sheet)
     {
         if(list->at(i) == sheet)
         {
-           list->at(i)->close();
+            list->at(i)->close();
             list->removeAt(i);
             break;
         }
@@ -75,12 +88,6 @@ void MainWindow::SheetClose(PlayerSheet* sheet)
 void MainWindow::FlipCoin()
 {
     int roll = qrand() % ((1 + 1) - 0) + 0;
-    if(coinLabel != NULL)
-    {
-        delete coinLabel;
-        coinLabel = NULL;
-    }
-    coinLabel = new QLabel(this);
     if(roll == 0)
     {
         QPixmap pixmap(":/images/heads.png");
@@ -97,19 +104,18 @@ void MainWindow::FlipCoin()
         coinLabel->move((this->width()/2) - coinLabel->width()/2,(this->height()/2) - coinLabel->height()/2);
         coinLabel->show();
     }
+    coinLabel->show();
 }
 
 void MainWindow::mousePressEvent(QMouseEvent *)
 {    
-    deleteCoin();
-}
-
-void MainWindow::deleteCoin()
-{
-    if(coinLabel != NULL)
+    if(coinLabel->isVisible())
     {
-        delete coinLabel;
-        coinLabel = NULL;
+        coinLabel->hide();
+    }
+    if(aboutFrame->isVisible())
+    {
+        aboutFrame->hide();
     }
 }
 
@@ -117,7 +123,14 @@ bool MainWindow::event(QEvent *event)
 {
     if(event->type() == QEvent::KeyPress || event->type() == QEvent::ShortcutOverride)
     {
-        deleteCoin();
+        if(coinLabel->isVisible())
+        {
+            coinLabel->hide();
+        }
+        if(aboutFrame->isVisible())
+        {
+            aboutFrame->hide();
+        }
     }
     return QMainWindow::event(event);
 }
@@ -130,3 +143,10 @@ void MainWindow::ResetSheets()
     }
 
 }
+
+void MainWindow::About()
+{
+    aboutLabel->setText("Version 0.0.1-4\n@Jarmo Kaataja");
+    aboutFrame->move((this->width()/2) - aboutFrame->width()/2,(this->height()/2) - aboutFrame->height()/2);
+    aboutFrame->show();
+}
