@@ -22,9 +22,10 @@ private:
     QList<PlayerSheet*> *list;
     virtual void mousePressEvent(QMouseEvent *);
     virtual bool event(QEvent *event);
-
     QLabel *coinLabel;
-    void deleteCoin();
+    QLabel *aboutLabel;
+    QFrame *aboutFrame;
+    QVBoxLayout *aboutLayout;
 
 signals:
     void StartTimerSignal(int);
@@ -37,6 +38,7 @@ public slots:
 
 private slots:
     void FlipCoin();
+    void About();
 };
 
 #endif // MAINWINDOW_H
