@@ -28,16 +28,15 @@ QLineEditScaledFont::QLineEditScaledFont(QWidget *parent) :
 
 void QLineEditScaledFont::resizeEvent(QResizeEvent *)
 {
-
+    emit resizeComplete();
 }
 
 void QLineEditScaledFont::TimerTick()
 {
-    int padding = 15;
+    padding = 15;
     QFont font = this->font();
-    fontMetrics = new QFontMetrics(font);
-
-    while( width() > (fontMetrics->width(text()) + padding + 10) && height() > (fontMetrics->height()))
+    fontMetrics = new QFontMetrics(font);    
+    while( width() > (fontMetrics->width(text()) + padding) && height() > (fontMetrics->height()))
     {
         font.setPointSize(font.pointSize() + 1);
         setFont(font);
@@ -46,6 +45,7 @@ void QLineEditScaledFont::TimerTick()
         fontMetrics = new QFontMetrics(font);
 
     }
+
 }
 
 void QLineEditScaledFont::StartTimer(int delay)
