@@ -8,6 +8,7 @@ class QLineEditScaledFont : public QLineEdit
     Q_OBJECT
 public:
     explicit QLineEditScaledFont(QWidget *parent = 0);
+    int padding;
 
 private:
     virtual void resizeEvent(QResizeEvent *);
@@ -20,6 +21,9 @@ private slots:
     void StartTimer(int);
     void textChanged(QString);
 
+signals:
+    void resizeComplete();
+
 };
 
 #endif // QLINEEDITSCALEDFONT_H
